==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-spanish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Tu nombre");
define("_OK","Aceptar");
define("_COMMENT","Comentario");
define("_CONFIGURE","Configurar");
define("_LOGINCREATE","Entrar/Crear Cuenta");
define("_THRESHOLD","Puntos");
define("_NOCOMMENTS","Sin Comentarios");
define("_NESTED","Anidados");
define("_FLAT","Plano");
define("_THREAD","Discusin");
define("_OLDEST","Viejos Primero");
define("_NEWEST","Nuevos Primero");
define("_HIGHEST","Mayor Puntuacin Primero");
define("_COMMENTSWARNING","Los comentarios son propiedad de quien los envi. No somos responsables por su contenido.");
define("_SCORE","Puntuacin");
define("_USERINFO","Informacin del Usuario");
define("_READREST","Leer el resto del comentario...");
define("_REPLY","Responder a sto");
define("_REPLYMAIN","Enviar Comentario");
define("_NOSUBJECT","Sin Ttulo");
define("_NOANONCOMMENTS","No se permiten comentarios Annimos, <a href=\"modules.php?name=Your_Account\">Regstrese</a> por favor");
define("_PARENT","Padre");
define("_ROOT","Raz");
define("_UCOMMENT","Comentario");
define("_ALLOWEDHTML","HTML Permitido:");
define("_POSTANON","Envo Annimo");
define("_EXTRANS","Extrans (html tags a texto)");
define("_HTMLFORMATED","Formateado HTML");
define("_PLAINTEXT","Texto Plano");
define("_ONN","en...");
define("_SUBJECT","Ttulo");
define("_SURVEYCOM","Enviar Comentario a la Encuesta");
define("_SURVEYCOMPRE","Previsualizar Comentario a la Encuesta");
define("_NOTRIGHT","Algo no ha funcionado al pasar una variable a su funcin. Este mensaje es slo para dejar cosas claras en la va");
define("_DIRECTCOM","Comentario Directo a la Encuesta...");
define("_SENDAMSG","Enviar un Mensaje");
define("_PASTSURVEYS","Encuestas Pasadas");



define("_LVOTES","Votos");
define("_TOTALVOTES","Votos Totales:");
define("_VOTING","Sala de Votacin");
define("_OTHERPOLLS","Otras Encuestas");
define("_CURRENTSURVEY","Encuesta Actual");
define("_CURRENTPOLLRESULTS","Resultados de la Encuesta Actual");
define("_PREVIEW","Vista Previa");
define("_REFRESH","Recargar");
define("_SURVEYS","Encuestas");
define("_ATTACHEDTOARTICLE","- Pegada al artculo:");
define("_SURVEYSATTACHED","Encuestas Pegadas a Noticias");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-spanish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Tu nombre");
define("_OK","Aceptar");
define("_COMMENT","Comentario");
define("_CONFIGURE","Configurar");
define("_LOGINCREATE","Entrar/Crear Cuenta");
define("_THRESHOLD","Puntos");
define("_NOCOMMENTS","Sin Comentarios");
define("_NESTED","Anidados");
define("_FLAT","Plano");
define("_THREAD","Discusin");
define("_OLDEST","Viejos Primero");
define("_NEWEST","Nuevos Primero");
define("_HIGHEST","Mayor Puntuacin Primero");
define("_COMMENTSWARNING","Los comentarios son propiedad de quien los envi. No somos responsables por su contenido.");
define("_SCORE","Puntuacin");
define("_USERINFO","Informacin del Usuario");
define("_READREST","Leer el resto del comentario...");
define("_REPLY","Responder a sto");
define("_REPLYMAIN","Enviar Comentario");
define("_NOSUBJECT","Sin Ttulo");
define("_NOANONCOMMENTS","No se permiten comentarios Annimos, <a href=\"modules.php?name=Your_Account\">Regstrese</a> por favor");
define("_PARENT","Padre");
define("_ROOT","Raz");
define("_UCOMMENT","Comentario");
define("_ALLOWEDHTML","HTML Permitido:");
define("_POSTANON","Envo Annimo");
define("_EXTRANS","Extrans (html tags a texto)");
define("_HTMLFORMATED","Formateado HTML");
define("_PLAINTEXT","Texto Plano");
define("_ONN","en...");
define("_SUBJECT","Ttulo");
define("_SURVEYCOM","Enviar Comentario a la Encuesta");
define("_SURVEYCOMPRE","Previsualizar Comentario a la Encuesta");
define("_NOTRIGHT","Algo no ha funcionado al pasar una variable a su funcin. Este mensaje es slo para dejar cosas claras en la va");
define("_DIRECTCOM","Comentario Directo a la Encuesta...");
define("_SENDAMSG","Enviar un Mensaje");
define("_PASTSURVEYS","Encuestas Pasadas");
define("_LVOTES","Votos");
define("_TOTALVOTES","Votos Totales:");
define("_VOTING","Sala de Votacin");
define("_OTHERPOLLS","Otras Encuestas");
define("_CURRENTSURVEY","Encuesta Actual");
define("_CURRENTPOLLRESULTS","Resultados de la Encuesta Actual");
define("_PREVIEW","Vista Previa");
define("_REFRESH","Recargar");
define("_SURVEYS","Encuestas");
define("_ATTACHEDTOARTICLE","- Pegada al artculo:");
define("_SURVEYSATTACHED","Encuestas Pegadas a Noticias");

?>
